@@ -13,6 +13,9 @@ else:
     raise pymem.exception.ProcessNotFound(f"not any: {config.PROCESS_NAMES}")
 
 
+ARCH = 32 if pm.is_WoW64 else 64
+POINTER_SIZE = 4 if pm.is_WoW64 else 8
+
 read_pointer = pm.read_uint if pm.is_WoW64 else pm.read_longlong
 
 
